migrate_nodes

Function migrate_nodes 

pub async fn migrate_nodes(
    infra: &InfraContext<'_>,
    token: &str,
    target_hsm_name_vec: &[String],
    parent_hsm_name_vec: &[String],
    hosts_expression: &str,
    dry_run: bool,
    create_hsm_group: bool,
) -> Result<(Vec<String>, Vec<NodeMigrationResult>), Error>
Resolve hosts expression, curate HSM groups, validate targets, and migrate nodes between HSM groups.

Returns the list of xnames that were moved and the per-pair migration results for display.